# LicenseConstraintVariables

A dictionary of values to pass in to constraint evaluation. These values will be provided to the constraints via the 'input_vars' variable. Constraint variables are merged using the same priority as the constraints themselves. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


